"""Source code for pyprql."""
import prql_python as prql  # noqa: F401
from prql_python import to_sql as to_sql  # noqa: F401

__version__ = "0.5.13"
